@@ -1,14 +1,21 @@
 from itertools import chain
 from unittest import TestCase
-from pythautomata.model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as NFAComparator
-from pythautomata.model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as DFAComparator
+
+from pythautomata.automata.deterministic_finite_automaton import \
+    DeterministicFiniteAutomaton as DFA
+from pythautomata.automata.non_deterministic_finite_automaton import \
+    NondeterministicFiniteAutomaton as NFA
+from pythautomata.automata_definitions.bollig_habermehl_kern_leucker_automata import \
+    BolligHabermehlKernLeuckerAutomata
+from pythautomata.automata_definitions.omlin_giles_automata import \
+    OmlinGilesAutomata
 from pythautomata.automata_definitions.other_automata import OtherAutomata
 from pythautomata.automata_definitions.tomitas_grammars import TomitasGrammars
-from pythautomata.automata_definitions.omlin_giles_automata import OmlinGilesAutomata
-from pythautomata.automata_definitions.bollig_habermehl_kern_leucker_automata import BolligHabermehlKernLeuckerAutomata
-from pythautomata.automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
-from pythautomata.automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
-from pythautomata.utilities.automata_convertor import AutomataConvertor
+from pythautomata.model_comparators.dfa_comparison_strategy import \
+    DFAComparisonStrategy as DFAComparator
+from pythautomata.model_comparators.hopcroft_karp_comparison_strategy import \
+    HopcroftKarpComparisonStrategy as NFAComparator
+from pythautomata.utilities.automata_converter import AutomataConverter
 
 
 class TestAutomataComparison(TestCase):
@@ -72,7 +79,8 @@ class TestAutomataComparison(TestCase):
     def test_e_commerce_equivalence_with_reduced_version(self):
         e_commerce_automata = OtherAutomata.get_reduced_ecommerce_automaton()
         reduced_e_commerce_automata = OtherAutomata.get_reduced_ecommerce_automaton()
-        self.assertAreEquivalentFAs(e_commerce_automata, reduced_e_commerce_automata)
+        self.assertAreEquivalentFAs(
+            e_commerce_automata, reduced_e_commerce_automata)
 
     def test_comparator_equivalency_when_different_1(self):
         automaton = OtherAutomata.get_nfa_1()
@@ -88,7 +96,7 @@ class TestAutomataComparison(TestCase):
         automaton = OtherAutomata.get_nfa_1()
         equivalentDfa = OtherAutomata.get_dfa_1()
         comparator = DFAComparator()
-        automaton = AutomataConvertor.convert_nfa_to_dfa(automaton)
+        automaton = AutomataConverter.convert_nfa_to_dfa(automaton)
         counterexample = comparator.get_counterexample_between(
             automaton, equivalentDfa)
         self.assertIsNone(counterexample)
@@ -96,7 +104,7 @@ class TestAutomataComparison(TestCase):
     def test_comparator_returns_valid_counterexample(self):
         nfa = OtherAutomata.get_nfa_1()
         nonEquivalentDfa = OtherAutomata.get_dfa_2()
-        transformedNfa = AutomataConvertor.convert_nfa_to_dfa(nfa)                
+        transformedNfa = AutomataConverter.convert_nfa_to_dfa(nfa)
         comparator = DFAComparator()
         counterexample = comparator.get_counterexample_between(
             transformedNfa, nonEquivalentDfa)
@@ -107,7 +115,8 @@ class TestAutomataComparison(TestCase):
     def test_comparator_returns_valid_counterexample_2(self):
         ecommerce_automaton = OtherAutomata.get_ecommerce_automaton()
         different_ecommerce_automaton = OtherAutomata.get_different_ecommerce_automaton_NFA()
-        different_ecommerce_automaton = AutomataConvertor.convert_nfa_to_dfa(different_ecommerce_automaton)     
+        different_ecommerce_automaton = AutomataConverter.convert_nfa_to_dfa(
+            different_ecommerce_automaton)
         comparator = DFAComparator()
         counterexample = comparator.get_counterexample_between(
             ecommerce_automaton, different_ecommerce_automaton)
@@ -121,22 +130,22 @@ class TestAutomataComparison(TestCase):
         self.assertAreEquivalentFAs(dfa, nfa)
         self.assertAreEquivalentFAs(nfa, dfa)
 
-    def _areEquivalentFAs(self, automaton1, automaton2):        
+    def _areEquivalentFAs(self, automaton1, automaton2):
         if type(automaton1) == DFA and type(automaton2) == DFA:
             comparator = DFAComparator()
-        elif type(automaton1) == NFA and type(automaton2)== NFA:
+        elif type(automaton1) == NFA and type(automaton2) == NFA:
             comparator = NFAComparator()
         else:
             if type(automaton1) == DFA:
-                automaton2 = AutomataConvertor.convert_nfa_to_dfa(automaton2)                
+                automaton2 = AutomataConverter.convert_nfa_to_dfa(automaton2)
             else:
-                automaton1 = AutomataConvertor.convert_nfa_to_dfa(automaton1)    
+                automaton1 = AutomataConverter.convert_nfa_to_dfa(automaton1)
             comparator = DFAComparator()
         areEquivalent = comparator.are_equivalent(automaton1, automaton2)
         return areEquivalent
 
-    def assertAreEquivalentFAs(self, automaton1, automaton2):        
+    def assertAreEquivalentFAs(self, automaton1, automaton2):
         assert(self._areEquivalentFAs(automaton1, automaton2))
 
-    def assertAreNotEquivalentFAs(self, automaton1, automaton2):        
+    def assertAreNotEquivalentFAs(self, automaton1, automaton2):
         self.assertFalse(self._areEquivalentFAs(automaton1, automaton2))
